@@ -4,7 +4,7 @@ from __future__ import unicode_literals
 from __future__ import print_function
 
 
-class DataSource:
+class DataSource(object):
     """
     Datasource containing a 'dict' like object
     acting as the main datasource for the gridadmin
@@ -18,14 +18,14 @@ class DataSource:
         self._source = source
 
     def keys(self):
-        keys = self._source.keys()
+        keys = list(self._source.keys())
         # Append meta to keys if not present
         if 'meta' not in keys:
             keys.append('meta')
         return keys
 
     def set(self, name, value):
-        raise NotImplemented()
+        raise NotImplementedError()
 
     def get(self, name):
         # meta is special
